simple_floating_panel library

Classes

MasterPanel
A master panel is not managed by other panels, will have its own lifecycle, SlavePanels can be attached to it, but it will not be automatically closed when the attached panels are closed.
MasterPanelEntry
Panel
PanelConfig
PanelConstraints
Represents the constraints for a panel, including minimum and maximum sizes, screen size, and edge visibility threshold.
PanelController
PanelEntry
PanelEntryScope
PanelGeometry
Represents the geometry of a panel, including its position and size.
PanelMasterScope
An InheritedWidget that provides access to the master panel's id for descendant widgets within a panel.
PanelMoveHandle
Marks the subtree that drives the "move" gesture for the enclosing panel.
PanelPositioner
A strategy for determining the initial position of a panel when it is opened.
PanelPreviewStyle
PanelResizeEdgeHandle
A region that resizes the enclosing panel in direction when dragged.
PanelResizeHandle
Wraps child with eight invisible PanelResizeHandles — one per edge and one per corner — laid out via a Stack.
PanelScope
An InheritedWidget that provides access to the PanelController for descendant widgets within a panel.
PanelSizer
PanelViewController
Controller for individual panel views, allowing manipulation of the panel's state and geometry.
PanelViewDelegate
PanelViewState
Represents the state of a panel view, including its title, mode, and geometry.
SlavePanel
A panel that is attached to a specific parent panel, and will be automatically closed when the parent panel is closed.
SlavePanelEntry

Enums

PanelMode
Mode for how the panels are displayed within the floating panel.
PanelViewMode
Mode for how the panel view is displayed within its panel.
ResizeDirection

Typedefs

PanelWidgetBuilder = Widget Function(BuildContext context, PanelViewController controller)