MasterPanelEntry class final

Inheritance

Properties

addRepaintBoundary bool
finalinherited
builder PanelWidgetBuilder
finalinherited
controller PanelViewController
finalinherited
hashCode int
The hash code for this object.
no setterinherited
id Object
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slaves List<Object>
final

Methods

attach(Object attachedPanelId) MasterPanelEntry
detach(Object attachedPanelId) MasterPanelEntry
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited